@@ -49,20 +49,13 @@ def execute(command, cwd='/'):
     :param cwd: 执行环境
     :return: 输出，错误信息(bytes类型)
     """
-    try:
-        return_info = subprocess.Popen(command,cwd=cwd,  shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
-        while True:
-            next_line = return_info.stdout.readline()
-            return_line = next_line.decode("utf-8", "ignore")
-            if return_line == '' and return_info.poll() != None:
-                break
-            print(return_line)
+    command = 'bash --login -c "%s" ' % command
+    sub = subprocess.Popen(command, cwd=cwd, stdin=subprocess.PIPE, stdout=subprocess.PIPE,
+                           stderr=subprocess.PIPE, shell=True)
+    (stdout, stderr) = sub.communicate(timeout=3600)
+    if sub.returncode != 0:
+        raise Exception(stderr.decode('utf-8', 'ignore'), stdout.decode('utf-8', 'ignore'))
 
-        returncode = return_info.wait()
-        if returncode:
-            raise subprocess.CalledProcessError(returncode, return_info)
-    except Exception as e:
-        print(e)
 
 def delete_dir_then_move_dir(file_from, file_to):
     """
